// Simple example of full-connected network.
// It takes a number and multiplies it by 1.

#include <iostream>
#include <vector>

#include <elcorenn/elcorenn.h>

const auto batchSize = 32;

int main() {
  std::string home_dir = getenv("HOME");
  std::string examples_dir = home_dir + "/elcorenn-examples-data";
  std::string model_json = examples_dir + "/models/fc_model.json";
  std::string model_weights = examples_dir + "/models/fc_weights.bin";

  // Init ElcoreNN resources
  InitBackend();

  std::vector<float> inputData;
  std::vector<float> outputData(batchSize);

  // Input data preparation
  inputData.reserve(batchSize);
  for (auto i = 0; i < batchSize; i++) {
    inputData.push_back(static_cast<float>(i) + 1.0f);
  }

  // Load model from files
  auto id = LoadModel(model_json.c_str(), model_weights.c_str());

  // Вычисление сети
  float* inputs[1] = {inputData.data()};
  float* outputs[1] = {outputData.data()};

  InvokeModel(id, inputs, outputs, batchSize);

  // Print results
  std::cout << "Input:" << std::endl;
  for (auto i : inputData) {
    std::cout << " " << i;
  }
  std::cout << std::endl;

  std::cout << "Output: " << std::endl;
  for (auto i : outputData) {
    std::cout << " " << i;
  }
  std::cout << std::endl;

  return 0;
}
